@@ -1,6 +1,6 @@
 package App::CharmKit::Command::init;
-$App::CharmKit::Command::init::VERSION = '0.002';
-# ABSTRACT: Initialization of project
+$App::CharmKit::Command::init::VERSION = '0.004';
+# ABSTRACT: Generate a charm project
 
 
 
@@ -25,7 +25,6 @@ sub opt_spec {
     );
 }
 
-sub abstract { 'Generate a charm skeleton.'}
 sub usage_desc {'%c init [--options] <charm-name>'}
 
 sub validate_args {
@@ -55,14 +54,20 @@ sub execute {
     printf("Initializing project %s\n", $path->absolute);
 
     my $default_maintainer = 'Joe Hacker';
-    my $default_category = $opt->{category};
+    my $default_category   = $opt->{category};
     @ARGV = ();    # IO::Prompter workaround
-    $project->{name}        = prompt "Name [default $path]:", -def => "$path";
-    $project->{summary}     = prompt 'Summary:';
+    $project->{name}    = prompt "Name [default $path]:",    -def => "$path";
+    $project->{version} = prompt "Version [default 0.0.1]:", -def => '0.0.1';
+    $project->{summary} = prompt 'Summary:';
     $project->{description} = prompt 'Description:';
-    $project->{maintainer}  = prompt "Maintainer [default $default_maintainer]:", -def => $default_maintainer;
-    $project->{categories}  = [prompt "Category [default: $default_category]:", -def => $default_category];
-    $project->{license}     = prompt 'License [? for list]:',
+    $project->{maintainer} =
+      prompt "Maintainer [default $default_maintainer]:",
+      -def => $default_maintainer;
+    $project->{categories} = [
+        prompt "Category [default: $default_category]:",
+        -def => $default_category
+    ];
+    $project->{license} = prompt 'License [? for list]:',
       -menu => {
         agpl_3      => 'AGPL_3',
         apache_1_1  => 'Apache_1_1',
@@ -92,10 +97,10 @@ sub execute {
 
     $self->init($path, $project);
     if ($opt->{with_hooks}) {
-      {
-        local $CWD = $path->absolute;
-        $self->create_all_hooks;
-      }
+        {
+            local $CWD = $path->absolute;
+            $self->create_all_hooks;
+        }
     }
     printf("Project skeleton created.\n");
 }
@@ -110,11 +115,11 @@ __END__
 
 =head1 NAME
 
-App::CharmKit::Command::init - Initialization of project
+App::CharmKit::Command::init - Generate a charm project
 
 =head1 VERSION
 
-version 0.002
+version 0.004
 
 =head1 SYNOPSIS
 
