@@ -1,9 +1,12 @@
 package App::CharmKit::Helper;
-$App::CharmKit::Helper::VERSION = '0.002';
+$App::CharmKit::Helper::VERSION = '0.004';
 # ABSTRACT: charm helpers
 
 
 use App::CharmKit::Sys qw/execute/;
+use YAML::Tiny;
+use JSON::PP;
+use Text::MicroTemplate;
 use Exporter qw/import/;
 
 our @EXPORT = qw/config_get
@@ -11,9 +14,19 @@ our @EXPORT = qw/config_get
   relation_get
   relation_set
   relation_list
+  service_control
   open_port
   close_port
-  unit_get/;
+  unit_get
+  json
+  yaml
+  tmpl/;
+
+sub json { JSON::PP->new->utf8; }
+
+sub yaml { YAML::Tiny->new(@_); }
+
+sub tmpl { Text::MicroTemplate->new(@_); }
 
 sub service_control {
     my $service_name = shift;
@@ -116,7 +129,7 @@ App::CharmKit::Helper - charm helpers
 
 =head1 VERSION
 
-version 0.002
+version 0.004
 
 =head1 SYNOPSIS
 
@@ -124,7 +137,7 @@ version 0.002
 
 or
 
-  use charm -helper;
+  use charm;
 
   my $port = config_get 'port';
   my $database = relation_get 'database';
@@ -136,6 +149,18 @@ Charm helpers for composition
 
 =head1 FUNCTIONS
 
+=head2 json
+
+Wrapper for JSON::PP
+
+=head2 yaml
+
+Wrapper for YAML::Tiny
+
+=head2 tmpl
+
+Wrapper for Text::MicroTemplate
+
 =head2 service_control(STR service_name, STR action)
 
 Controls a upstart service
