@@ -1,10 +1,11 @@
 package App::CharmKit::Role::Init;
-$App::CharmKit::Role::Init::VERSION = '0.002';
+$App::CharmKit::Role::Init::VERSION = '0.004';
 # ABSTRACT: Initialization of new charms
 
-use Carp;
 use YAML::Tiny;
+use JSON::PP;
 use Software::License;
+use Module::Runtime qw(use_module);
 use Moo::Role;
 
 sub init {
@@ -57,27 +58,38 @@ done_testing;
     );
     $path->child('src/tests/00-basic.test')->spew_utf8($basic_test);
 
+    # charmkit.json
+    my $json          = JSON::PP->new->utf8->pretty;
+    my $charmkit_meta = {
+        name       => $project->{name},
+        version    => $project->{version},
+        maintainer => $project->{maintainer},
+        series     => ['precise', 'trusty']
+    };
+    my $json_encoded = $json->encode($charmkit_meta);
+    $path->child('charmkit.json')->spew_utf8($json_encoded);
+
     # metadata.yaml
-    $yaml = YAML::Tiny->new($project);
+    $yaml = YAML::Tiny->new(
+        {   name        => $project->{name},
+            summary     => $project->{summary},
+            description => $project->{description},
+            maintainer  => $project->{maintainer},
+            categories  => $project->{categories},
+            license     => $project->{license}
+        }
+    );
     $yaml->write($path->child('metadata.yaml'));
 
     # config.yaml
-    $yaml = YAML::Tiny->new(
-        {   options => {
-                supports_charmkit => {
-                    default => 'true',
-                    description =>
-                      'Supports extended functionality from App::CharmKit',
-                    type => 'boolean'
-                }
-            }
-        }
-    );
-    $yaml->write($path->child('config.yaml'));
+    $path->child('config.yaml')->touch;
+
+    # copyright
+    $path->child('copyright')->touch;
 
     # LICENSE
     my $class = "Software::License::" . $project->{license};
-    eval "require $class;";
+    use_module($class);
     my $license = $class->new({holder => $project->{maintainer}});
     my $year    = $license->year;
     my $notice  = $license->notice;
@@ -120,7 +132,7 @@ App::CharmKit::Role::Init - Initialization of new charms
 
 =head1 VERSION
 
-version 0.002
+version 0.004
 
 =head1 METHODS
 
