@@ -1,19 +1,18 @@
 package App::CharmKit::Sys;
-$App::CharmKit::Sys::VERSION = '0.002';
+$App::CharmKit::Sys::VERSION = '0.004';
 # ABSTRACT: system utilities
 
 
 use IPC::Run qw(run timeout);
 use Exporter qw(import);
 
-our @EXPORT = qw/execute apt_inst/;
+our @EXPORT = qw/execute apt_inst apt_upgrade apt_update/;
 
 sub execute {
     my ($command) = @_;
     my $result = run $command, \my $stdin, \my $stdout, \my $stderr;
     chomp for ($stdout, $stderr);
 
-    die $stderr unless $? eq 0;
     +{  stdout    => $stdout,
         stderr    => $stderr,
         has_error => $? > 0,
@@ -29,6 +28,18 @@ sub apt_inst {
     return $ret->{stdout};
 }
 
+sub apt_upgrade {
+    my $cmd = ['apt-get', '-qyf', 'dist-upgrade'];
+    my $ret = execute($cmd);
+    return $ret->{stdout};
+}
+
+sub apt_update {
+    my $cmd = ['apt-get', 'update'];
+    my $ret = execute($cmd);
+    return $ret->{stdout};
+}
+
 1;
 
 __END__
@@ -43,20 +54,19 @@ App::CharmKit::Sys - system utilities
 
 =head1 VERSION
 
-version 0.002
+version 0.004
 
 =head1 SYNOPSIS
 
-use charm -sys;
+  use charm -sys;
 
 or
 
-use App::CharmKit::Sys;
+  use App::CharmKit::Sys;
 
-# Exposes Path::Tiny
-my $curpath = path('.');
-my $homepath = path('~');
-$homepath->child('.config')->mkpath;
+  apt_update();
+  apt_upgrade();
+  apt_inst(['nginx-common', 'redis-server']);
 
 =head1 DESCRIPTION
 
@@ -76,7 +86,19 @@ Executes a local command:
 
 Installs packages via apt-get
 
-   apt_inst ['nginx'];
+   apt_inst(['nginx']);
+
+=head2 apt_upgrade()
+
+Upgrades system
+
+   apt_upgrade();
+
+=head2 apt_update()
+
+Update repository sources
+
+   apt_update();
 
 =head1 AUTHOR
 
